Drivers
=======

Zuul provides an API for extending its functionality to interact with
other systems.

.. autoclass:: zuul.driver.Driver
   :members:

.. autoclass:: zuul.driver.ConnectionInterface
   :members:

.. autoclass:: zuul.driver.SourceInterface
   :members:

.. autoclass:: zuul.driver.TriggerInterface
   :members:

.. autoclass:: zuul.driver.ReporterInterface
   :members:
